flutter_semantic_lints library
Custom lint rules that detect semantically meaningless Flutter code.
This package focuses on conflicting parameters, useless parameters, and no-effect widgets. It does not provide style, naming, formatting, or architecture rules.
Functions
-
createPlugin(
) → PluginBase -
Creates the custom_lint plugin for
flutter_semantic_lints.